@@ -410,12 +410,16 @@ def main(args):
             atoms.append(' Bacilli \n\n')
             atoms = atoms + bacilli_list
             #write atom definition file
-            f= open(f"./runs/atom_{culture.n_cyanos}_{culture.n_ecw}_{culture.SucPct}_{r}.in","w+")
+            f= open(f"runs/atom_{culture.n_cyanos}_{culture.n_ecw}_{culture.SucPct}_{r}.in","w+")
             f.writelines(atoms)
-
-        #write initial conditions pickle file
-        dumpfile = open(f"./runs/run_{culture.n_cyanos}_{culture.n_ecw}_{culture.SucPct}.pkl",'wb')
-        pickle.dump(CellInfo,dumpfile)
+        RUN_DIR = Path('runs') / f'Run_{culture.n_cyanos}_{culture.n_ecw}_{culture.SucPct}_{args.reps}'
+        if not os.path.isdir(RUN_DIR):
+            os.mkdir(RUN_DIR)
+            #os.mkdir(f'runs/Run_{culture.n_cyanos}_{culture.n_ecw}_{culture.SucPct}_{args.reps}')
+        #write initial conditions json file
+        dumpfile = open(RUN_DIR / 'metadata.json','w')
+        #dumpfile = open(f"/runs/Run_{culture.n_cyanos}_{culture.n_ecw}_{culture.SucPct}_{args.reps}/metadata.json",'w')
+        json.dump(CellInfo, dumpfile, indent = 6)
         dumpfile.close()
         ###
 
@@ -496,8 +500,9 @@ def main(args):
                                     'USER' : args.user,'Replicates'  : args.reps,
                                     'SucPct' : culture.SucPct,'n_cyanos' : culture.n_cyanos,
                                     'n_ecw' : culture.n_ecw,'id': global_coll_id})
-    f= open(f"./RunBatch.slurm","w+")
-    f.writelines(result)
+    # TODO update slurm script
+    #f= open(f"./RunBatch.slurm","w+")
+    #f.writelines(result)
     _logger.info("Script ends here")
 
 def run():
